@@ -48,6 +48,13 @@ namespace Plasma
 class ConfigLoader;
 } // namespace Plasma
 
+/**
+ * @class AppletInterface
+ *
+ * @short This class is exposed to applets in QML as the attached property Plasmoid
+ *
+ * \@import org.kde.plasma.Plasmoid
+ */
 class AppletInterface : public PlasmaQuick::AppletQuickItem
 {
     Q_OBJECT
@@ -346,6 +353,9 @@ protected Q_SLOTS:
 protected:
     bool eventFilter(QObject *watched, QEvent *event);
 
+private Q_SLOTS:
+    void destroyedChanged(bool destroyed);
+
 private:
 
     QStringList m_actions;
@@ -362,7 +372,10 @@ private:
     Plasma::Types::BackgroundHints m_backgroundHints;
     bool m_busy : 1;
     bool m_hideOnDeactivate : 1;
+
     friend class ContainmentInterface;
+    //This is used by ContainmentInterface
+    QPointF m_positionBeforeRemoval;
 };
 
 QML_DECLARE_TYPEINFO(AppletInterface, QML_HAS_ATTACHED_PROPERTIES)
